@@ -98,19 +98,48 @@ class Socks(User):
         return "socks"
 
 class Vless(User):
-    def __init__(self, uuid, user_number, encryption=None, email=None):
+    def __init__(self, uuid, user_number, encryption=None, email=None, network=None, path=None, host=None):
         super(Vless, self).__init__(user_number, uuid, email)
         self.encryption = encryption
+        self.path = path
+        self.host = host
+        self.network = network
+
+    def __str__(self):
+        email = ""
+        if self.user_info:
+            email = "Email: {}".format(self.user_info)
+        result = '''
+{email}
+ID: {password}
+Encryption: {self.encryption}
+Network: {network}
+'''.format(self=self, password=self.password, email=email, network=self.stream()).strip() + "\n"
+        return result
+    
+    def stream(self):
+        if self.network == "ws":
+            return "VLESS WebSocket host: {0}, path: {1}".format(self.host, self.path)
+        elif self.network == "tcp":
+            return "VLESS"
+
+    def link(self, ip, port, tls):
+        return ""
+
+class Xtls(Vless):
+    def __init__(self, uuid, user_number, encryption=None, email=None, flow=""):
+        super(Xtls, self).__init__(uuid, user_number, encryption, email)
+        self.flow = flow
 
     def __str__(self):
         if self.user_info:
-            return "Email: {self.user_info}\nProtocol: {network}\nId: {password}\nEncryption: {self.encryption}\n".format(self=self, network=self.stream(), password=self.password)
+            return "Email: {self.user_info}\nProtocol: {network}\nId: {password}\nEncryption: {self.encryption}\nFlow: {self.flow}\n".format(self=self, network=self.stream(), password=self.password)
         else:
-            return "Protocol: {network}\nId: {password}\nEncryption: {self.encryption}\n".format(self=self, network=self.stream(), password=self.password)
+            return "Protocol: {network}\nId: {password}\nEncryption: {self.encryption}\nFlow: {self.flow}\n".format(self=self, network=self.stream(), password=self.password)
     
     def stream(self):
-        return "VLESS"
-
+        return "VLESS_XTLS"
+    
     def link(self, ip, port, tls):
         return ""
 
@@ -191,7 +220,7 @@ class Group:
         self.index = index
 
     def show_node(self, index):
-        tls = _("open") if self.tls == "tls" else _("close")
+        tls = _("open") if self.tls in ("tls", "xtls") else _("close")
         tfo = "TcpFastOpen: {}".format(self.tfo) if self.tfo != None else ""
         dyp = "DynamicPort: {}".format(self.dyp) if self.dyp.status else ""
         port_way = "-{}".format(self.end_port) if self.end_port else ""
@@ -211,7 +240,7 @@ TLS: {tls}
 
     # print一个实例打印的字符串
     def __str__(self):
-        tls = _("open") if self.tls == "tls" else _("close")
+        tls = _("open") if self.tls in ("tls", "xtls") else _("close")
         tfo = "TcpFastOpen: {}".format(self.tfo) if self.tfo != None else ""
         dyp = "DynamicPort: {}".format(self.dyp) if self.dyp.status else ""
         port_way = "-{}".format(self.end_port) if self.end_port else ""
